@@ -74,7 +74,7 @@ def embed(url):
         embed = get_embed(url)
         ret = embed.html.replace('width="480"', '')
         ret = ret.replace('height="270"', '')
-        ret = ret.replace('src=', 'class="lazy" data-src=')
+        ret = ret.replace('src=', 'loading="lazy" title="embed" data-src=')
         return ret
     except EmbedException:
         return "<iframe title='embed' class='lazy' data-src='%s'></iframe>" % url
